<?php # $Id: lang_pl.inc.php 2093 2008-01-18 12:50:00Z garvinhicking $

/**
 *  @version $Revision: 2093 $
 *  @author Kostas CoSTa Brzezinski <costa@kofeina.net>
 *  EN-Revision: Revision of lang_en.inc.php
 */

@define('PLUGIN_EVENT_TEXTILE_NAME', 'Znacznik: Textile');
@define('PLUGIN_EVENT_TEXTILE_DESC', 'Parsuj całą treść przez moduł konwertera Textile');
@define('PLUGIN_EVENT_TEXTILE_TRANSFORM', '<a href="%s">Textile</a>-format dozwolony');

?>
